@@ -30,7 +30,7 @@ sub import {
       if ( @_ && lc( $_[0] ) eq "pool" );
 }
 
-our $VERSION = '1.50';
+our $VERSION = '1.51';
 
 our $drh    = undef;    # will hold driver handle
 our $err    = 0;        # will hold any error codes
@@ -963,6 +963,10 @@ Once this is turned on, you will need to choose a database specific attribute al
 
   DBI->connect('dbi:Mock:MySQL', '', '');
 
+Or, by using the database name if using driver DSNs:
+
+  DBI->connect('dbi:Mock:host=localhost;port=3306;database=MySQL', '', '');
+
 The 'MySQL' in the DSN will be picked up and the MySQL specific attribute aliasing will be used.
 
 Right now there is only minimal support for MySQL and MariaDB:
